@@ -50,19 +50,31 @@ class Credentials:
         self.setSparkConf("fs.azure.account.custom.token.provider.class", self.spark.conf.get(
             "spark.databricks.passthrough.adls.tokenProviderClassName"))
 
-    def setStorageCredentialsSPN(self, scope, spn_name, account=None):
+    def setStorageCredentialsSPN(self, scope, spn_name, account=None, _tenantId=None, _applicationId=None, _applicationSecret=None):
         """
         Databricks: Set configuration to use an SPN/OAuth to access Azure Storage Accounts
         If account is missing or None - this is set at global level for all accounts.
         Expects the secrets to be
             {spn_name}-spn-tenant
             {spn_name}-spn-id
-            {spn_name}-spn-secret        
+            {spn_name}-spn-secret   
+        Alternatively, these can be passed as params _tenantId,_applicationId and _applicationSecret     
         """
-        tenandId = self.dbutils.secrets.get(scope, f'{spn_name}-spn-tenant')
-        applicationId = self.dbutils.secrets.get(scope, f'{spn_name}-spn-id')
-        applicationSecret = self.dbutils.secrets.get(
-            scope, f'{spn_name}-spn-secret')
+        if _tenantId != None:
+            tenandId = _tenantId
+        else:
+            tenandId = self.dbutils.secrets.get(
+                scope, f'{spn_name}-spn-tenant')
+        if _applicationId != None:
+            applicationId = _applicationId
+        else:
+            applicationId = self.dbutils.secrets.get(
+                scope, f'{spn_name}-spn-id')
+        if _applicationSecret != None:
+            applicationSecret = _applicationSecret
+        else:
+            applicationSecret = self.dbutils.secrets.get(
+                scope, f'{spn_name}-spn-secret')
         endpoint = "https://login.microsoftonline.com/" + tenandId + "/oauth2/token"
         if account != None:
             suffix = ".{account}.dfs.core.windows.net"
@@ -78,13 +90,17 @@ class Credentials:
         self.setSparkConf(
             f"fs.azure.account.oauth2.client.endpoint{suffix}", endpoint)
 
-    def setStorageCredentialsKey(self, scope, account):
+    def setStorageCredentialsKey(self, scope, account, _key=None):
         """
         Databricks: Set configuration to use Storage Key to access Azure Storage Accounts
         Expects the storage key to be stored as {account}-storage-access-key
+        Alternatively the key can be passed as _key parameter
         """
-        secret = self.dbutils.secrets.get(
-            scope, f'{account}-storage-access-key')
+        if _key != None:
+            secret = _key
+        else:
+            secret = self.dbutils.secrets.get(
+                scope, f'{account}-storage-access-key')
         self.setSparkConf(
             f"fs.azure.account.auth.type.{account}.dfs.core.windows.net", "SharedKey")
         self.setSparkConf(
