@@ -6,7 +6,7 @@
 # # define the pipeline array of tasks
 # TaskBuilder.generate(pipeline)
 #
-
+import json
 try:
     import dlt
 except ImportError:
@@ -39,13 +39,35 @@ class TaskBuilder:
         self.spark = spark
         self.storage = storage
 
+    def generateFromFile(self, pipelineJSONFile, params={}):
+        try:
+            with open(pipelineJSONFile) as f:
+                contentlines = f.readlines()
+                pipelineJSON = "\n".join(contentlines)
+                self.generateFromJSON(pipelineJSON, params)
+        except FileNotFoundError as err:
+            raise Exception(
+                "Please check path of JSON file. {0}".format(err))
+
+    def generateFromJSON(self, pipelineJSON, params={}):
+        try:
+            pipeline = json.loads(pipelineJSON)
+            for task in pipeline:
+                for key, value in task.items():
+                    if (type(value) is str) and (value.__contains__("{")):
+                        task[key] = value.format(**params)
+                self.generateTask(**task)
+        except json.decoder.JSONDecodeError as err:
+            raise Exception(
+                "Please check JSON for syntax error. {0}".format(err))
+
     def generate(self, pipeline):
         for task in pipeline:
             self.generateTask(**task)
 
     def generateTask(self, name, sql, type="dlt-view", comment="", temporary=True,
                      nested=None, spark_conf=None, table_properties=None, path=None,
-                     partition_cols=None, schema=None):
+                     partition_cols=None, schema=None, **extraargs):
         kwargs = {}
         # Define a Live Table
         if type == "dlt-table":
